/*******************/
/* SYNTAX FILE FOR STATA */
/*******************/

/*******************/
/* a:\week10_11.do */
/*******************/

/*******************/
/* Purpose: 1) hypothesis tests */
/* a.  chi-square  */
/* b.  ONE WAY ANOVA */
/* c.  two sample unpaired t-test with unequal variances */
/*********************************************************/

/*******************/
/* open log file to save output and syntax */
/*******************/

capture log close
log using "a:\week10_11.log", replace

/*******************/
/* initial set up commands, use with EVERY dofile */
/* 1. makes stata scroll through entire program rather than stopping */
/*    every time you come to the end of a screen of output, to make stata */
/*    stop scrolling, type: set more on */
/* 2. drop any programs that you may have created and would still be in memory */
/*    Stata knows that _all means all existing programs so you don't have to */
/*    specify a program name */
/* 3. close any data set that might be open */
/* 4. set the memory in Stata so that it can handle any dataset */
/*    (set to 10 megabytes) */
/* If using SMALL STATA, delete "set memory 10m" */
/*******************/

set more off
program drop _all
clear
set memory 10m

/*******************/
/* open data file */
/* If using small STATA, filename=census_small */
/*******************/

use "a:\census", clear

/*******************/
/* a.  chi-square (differences in nominal or ordinal distributions between two or more groups): */
/*******************/

tabulate inc_ord v1004, column nofreq chi2


/*******************/
/* b.  ONE WAY ANOVA (assessing three or more group level differences along a single interval level variable) */
/*******************/

oneway v303 county, scheffe tabulate


/*******************/
/* c.  two sample unpaired t-test with unequal variances */
/*******************/

* Example without a statistically significant difference

ttest v303, by(v1004) unequal welch

/*******************/
/* Example WITH a statistically significant difference. */
/* Comparing Baltimore and D.C. */
/* NOTE:  For this test, I need to drop all other cases other than D.C. and Baltimore */
/*******************/

keep if v1004==11 | v1008==510

ttest v303, by(county) unequal welch

/*******************/
* CORRESPONDENCE BETWEEN ANOVA AND T-TEST: scheffe test is two sample t-test with equal variances, HA: u1-u2~=0, 
/*******************/

use "a:\census", clear

oneway v303 v1004, tabulate scheffe
ttest v303, by(v1004)

/*******************/
/* closing output file so you can open it in word and print it there */
/*******************/

log close

