/*******************************/
/* STATA SYNTAX FILE */
/*******************************/

/*******************************/
/* NOTE:  everything that has an asterisk */
/* is a comment meant to help YOU remember */
/* what the syntax file is doing */
/* STATA ignores the comment and pays */
/* attention ONLY to the commands */
/*******************************/

/*******************************/
/* filename: a:\week3_4.do */
/* ALWAYS PUT THE NAME OF THE */
/* COMMAND FILE ON TOP */
/*******************************/

/*******************************/
/* Purpose:  */
/* 1. Displaying the contents of a file */
/*     a.  Full contents: codebook */
/*    b.  Brief contents: describe */
/* 2.  Frequency Distributions */
/*    a.  single level variable */
/*    b.  several variables at a time */
/* 3. histograms */
/* 4. command terminators */
/*******************************/

/***********************************/
/* Opening and starting an output file for results */
/* stata automatically records commands */
/* first you need to close any output file that might be open */
/**********************************/

capture log close
log using "a:\week3_4.log", replace

/*********************************/
/* Preparatory programming commands, we will worry about these later */
/* but always start out your syntax files with this. */
/* Delete "set memory 10m" if using small STATA */
/*********************************/

set more off
program drop _all
clear
set memory 10m

/********************************/
/* Opening data set */
/* If using small STATA, file=census_small */
/********************************/

use "a:\census", clear

/********************************/
/* 1.  Displaying contents of a file */
/********************************/

/********************************/
/* 1.   a.  Full contents: codebook */
/* NOTE:  Small stata does not have sufficient */
/* memory to do codebook, so do describe instead */
/********************************/

codebook, all

/********************************/
/* 1.b. Brief contents: describe */
/********************************/

describe


/********************/
/*2.  Frequency distribution */
/********************/

/********************/
/* 2. a.  nominal level variable */
/* v1004 is the census variable for State */
/********************/

tab1 v1004
 
/********************/
/* 2. c. multiple variables at one time */
/* Inc_ord is income divided into equal-sized */
/* intervals.  Inc_ord1 is income divided into */
/* equal FREQUENCY intervals.  Interpret both */
/********************/

tab1 v1004 inc_ord inc_ord1 

/**********************/
/*  3. histogram */
/* What is the implication of the shape of this histogram? */
/**********************/

graph inc_ord, hist bin (10) normal xlabel /*
*/ title ("Mean HH Income in Maryland and DC Census Tracts")

/***********************/
/* 4. command terminators */
/*    a. carriage return (default) */
/*    b. ; (semi-colon) */
/***********************/

/***********************/
/* 5.a. single line commands end in carriage return */
/***********************/

* example

tabulate inc_ord

/***********************/
/* 5. b. multi-line commands can end in carriage return or ; */
/* in order to change back and forth between terminators */
/* use #delimit command */
/***********************/

* example: EITHER use comments to hide carriage return from STATA

graph inc_ord, hist bin (10) normal xlabel /*
*/ title ("Mean HH Income in Maryland and DC Census Tracts")

* OR change to semi-colon to allow commands to be multi-line

#delimit;

graph inc_ord, hist bin (10) normal xlabel 
 title ("Mean HH Income in Maryland and DC Census Tracts");

* to change back to carriage return: ;

#delimit cr

/***********************/
/* closing and saving output file */
/***********************/

log close
