/*******************/
/* SYNTAX FILES FOR STATA */
/*******************/

/*******************/
/* a:\week7_8.do */
/* Purpose: To compute and display BIVARIATE statistics such as */
/* 1. bi-variate measures of central tendency & dispersion */
/* 2. bi-variate measures of central tendency and dispersion together: */
/*     box and whiskers plot */
/* 3. Cross-tabs (i.e. bi-variate frequency distribution) */
/* 4. Scatterplot (2 interval level variables) */
/* 5. bi-variate histogram */
/********************/

/**************************************/
/* Open log file to save output and syntax */
/**************************************/

capture log close
log using "a:\week7_8.log", replace

/**************************************/
/*Initial set up commands, use with EVERY dofile */
/* 1. makes stata scroll through entire program rather than stopping */
/*     every time you come to the end of a screen of output, to make */
/*     stata stop scrolling, type set more on */
/* 2. drop any programs that you may have created and would still be */
/*     in memory Stata knows that _all means all existing programs so */
/*     you don't need to specify a program name */
/* 3. close any data set that might be open */
/* 4. set the memory in Stata so that it can handle any dataset (set to */
/*     10 megabytes) */
/* If using small STATA, delete "set memory 10m" */
/***************************************/

set more off
program drop _all
clear
set memory 10m

/*****************/
/* Open data set */
/* If using small STATA, filename=census_small */
/*****************/ 
 use "a:\census.dta", clear

/*****************/
/* 1. bi-variate measures of central tendency & dispersion */
/* Comparing Income by county */
/******************/

* all except mode 
sort county
by county: sum v303, detail

* compare means and median of DC, Baltimore, PG, Montgomery  what does that tell you?

* mode
sort county
by county: egen modev303=mode(v303), minmode
by county: sum modev303

/********************/
/* 2. bi-variate measures of central tendency and dispersion together: */
/*     box and whiskers plot */
/********************/

sort county
graph v303, box ylabel title ("Mean HH income in MD/DC Census Tracts") by (county)

/********************/
/* 3. Scatterplot (2 interval level variables) */
/********************/
graph v303 v152, xlabel ylabel ti ("Mean Census Tract Income by % Black")

/********************/
/* 4. Cross-tabs (i.e. bi-variate frequency distribution */
/* Distribution of Income in $20k intervals (variable=inc_ord) */
/* by state */
/* Difficult to compare using counts since MD and DC */
/* are of different size, so compare percentages */
/********************/

tab inc_ord county, column nofreq

/********************/
/* if you wanted row %, just add "row", */
/* or cell % (% of total) add "cell", or count add "count" */
/********************/

/**********************/
/* 5. bi-variate histogram */
/**********************/
sort v1004
graph inc_ord, hist bin (10) normal xlabel ylabel by (v1004) /*
*/ title ("Mean HH Income in Maryland and DC Census Tracts")

/********************/
/* closing output file so you can open it in word and print it there */
/********************/
log close 
